==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/GeographicMarkerSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GeographicMapSeriesHostDescriptionMetadata } from "./GeographicMapSeriesHostDescriptionMetadata";
/**
 * @hidden
 */
export let GeographicMarkerSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class GeographicMarkerSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (GeographicMarkerSeriesDescriptionMetadata.a == null) {
                GeographicMarkerSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GeographicMarkerSeriesDescriptionMetadata.c(GeographicMarkerSeriesDescriptionMetadata.a);
            }
            if (a.k(GeographicMarkerSeriesDescriptionMetadata.a)) {
                return;
            }
            a.ab(GeographicMarkerSeriesDescriptionMetadata.a);
        }
        static c(a) {
            GeographicMapSeriesHostDescriptionMetadata.c(a);
            a.item("MarkerType", "ExportedType:string:MarkerType");
            a.item("MarkerType@names", "Unset;None;Automatic;Circle;Triangle;Pyramid;Square;Diamond;Pentagon;Hexagon;Tetragram;Pentagram;Hexagram;Hidden");
            a.item("MarkerThickness", "Number:double");
            a.item("MarkerOutlineMode", "ExportedType:string:MarkerOutlineMode");
            a.item("MarkerOutlineMode@names", "Auto;Normal;MatchMarkerBrush");
            a.item("MarkerFillMode", "ExportedType:string:MarkerFillMode");
            a.item("MarkerFillMode@names", "Auto;Normal;MatchMarkerOutline");
            a.item("MarkerTemplateRef", "(w:MarkerTemplate,wf:MarkerTemplate)DataRef::object");
            a.item("MarkerBrush", "Brush");
            a.item("MarkerOutline", "Brush");
            a.item("MaximumMarkers", "Number:int");
            a.item("ActualMarkerTemplateRef", "(w:ActualMarkerTemplate,wf:ActualMarkerTemplate)DataRef::object");
            a.item("ActualMarkerBrush", "Brush");
            a.item("ActualMarkerOutline", "Brush");
        }
        static d(a) {
            GeographicMarkerSeriesDescriptionMetadata.b(a);
            a.ac("GeographicMarkerSeries", GeographicMarkerSeriesDescriptionMetadata.a);
        }
    }
    GeographicMarkerSeriesDescriptionMetadata.$t = markType(GeographicMarkerSeriesDescriptionMetadata, 'GeographicMarkerSeriesDescriptionMetadata');
    GeographicMarkerSeriesDescriptionMetadata.a = null;
    return GeographicMarkerSeriesDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/GeographicMarkerSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GeographicMapSeriesHostDescriptionMetadata } from "./GeographicMapSeriesHostDescriptionMetadata";
/**
 * @hidden
 */
export let GeographicMarkerSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class GeographicMarkerSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (GeographicMarkerSeriesDescriptionMetadata.a == null) {
                GeographicMarkerSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GeographicMarkerSeriesDescriptionMetadata.c(GeographicMarkerSeriesDescriptionMetadata.a);
            }
            if (a.k(GeographicMarkerSeriesDescriptionMetadata.a)) {
                return;
            }
            a.ac(GeographicMarkerSeriesDescriptionMetadata.a);
        }
        static c(a) {
            GeographicMapSeriesHostDescriptionMetadata.c(a);
            a.item("MarkerType", "ExportedType:string:MarkerType");
            a.item("MarkerType@names", "Unset;None;Automatic;Circle;Triangle;Pyramid;Square;Diamond;Pentagon;Hexagon;Tetragram;Pentagram;Hexagram;Hidden");
            a.item("MarkerThickness", "Number:double");
            a.item("MarkerOutlineMode", "ExportedType:string:MarkerOutlineMode");
            a.item("MarkerOutlineMode@names", "Auto;Normal;MatchMarkerBrush");
            a.item("MarkerFillMode", "ExportedType:string:MarkerFillMode");
            a.item("MarkerFillMode@names", "Auto;Normal;MatchMarkerOutline");
            a.item("MarkerTemplateRef", "(w:MarkerTemplate,wf:MarkerTemplate)DataRef::object");
            a.item("MarkerBrush", "Brush");
            a.item("MarkerOutline", "Brush");
            a.item("MaximumMarkers", "Number:int");
            a.item("ActualMarkerTemplateRef", "(w:ActualMarkerTemplate,wf:ActualMarkerTemplate)DataRef::object");
            a.item("ActualMarkerBrush", "Brush");
            a.item("ActualMarkerOutline", "Brush");
        }
        static d(a) {
            GeographicMarkerSeriesDescriptionMetadata.b(a);
            a.ad("GeographicMarkerSeries", GeographicMarkerSeriesDescriptionMetadata.a);
        }
    }
    GeographicMarkerSeriesDescriptionMetadata.$t = markType(GeographicMarkerSeriesDescriptionMetadata, 'GeographicMarkerSeriesDescriptionMetadata');
    GeographicMarkerSeriesDescriptionMetadata.a = null;
    return GeographicMarkerSeriesDescriptionMetadata;
})();
